@@ -28,6 +28,7 @@ GHashTable* hash_table_create(void){
     g_hash_table_insert(hash, "AM Showers", _("AM Showers"));
     g_hash_table_insert(hash, "AM Snow", _("AM Snow"));
     g_hash_table_insert(hash, "AM Snow Showers", _("AM Snow Showers"));
+    g_hash_table_insert(hash, "Blowing Snow", _("Blowing Snow"));    
     g_hash_table_insert(hash, "CALM", _("CALM"));
     g_hash_table_insert(hash, "Clear", _("Clear"));
     g_hash_table_insert(hash, "Clear / Wind", _("Clear / Wind"));
@@ -48,9 +49,11 @@ GHashTable* hash_table_create(void){
     g_hash_table_insert(hash, "Few Snow Showers", _("Few Snow Showers"));
     g_hash_table_insert(hash, "First Quarter", _("First Quarter"));
     g_hash_table_insert(hash, "Fog", _("Fog"));
-    g_hash_table_insert(hash, "Foggy", _("Foggy"));    
+    g_hash_table_insert(hash, "Foggy", _("Foggy"));
+    g_hash_table_insert(hash, "Fog Early / Clearing Late", _("Fog Early / Clearing Late"));
     g_hash_table_insert(hash, "Fog Early / Clouds Late", _("Fog Early / Clouds Late"));
-    g_hash_table_insert(hash, "Fog Late", _("Fog Late"));    
+    g_hash_table_insert(hash, "Fog Late", _("Fog Late"));
+    g_hash_table_insert(hash, "Freezing Drizzle", _("Freezing Drizzle"));
     g_hash_table_insert(hash, "Full", _("Full"));
     g_hash_table_insert(hash, "Haze", _("Haze"));
     g_hash_table_insert(hash, "Heavy Rain", _("Heavy Rain"));
@@ -65,6 +68,7 @@ GHashTable* hash_table_create(void){
     g_hash_table_insert(hash, "Light Rain", _("Light Rain"));
     g_hash_table_insert(hash, "Light Rain / Fog", _("Light Rain / Fog"));    
     g_hash_table_insert(hash, "Light Rain / Wind", _("Light Rain / Wind"));
+    g_hash_table_insert(hash, "Light Rain / Wind Late", _("Light Rain / Wind Late"));    
     g_hash_table_insert(hash, "Light Rain Early", _("Light Rain Early"));
     g_hash_table_insert(hash, "Light Rain Late", _("Light Rain Late"));
     g_hash_table_insert(hash, "Light Rain Shower", _("Light Rain Shower"));    
@@ -72,6 +76,7 @@ GHashTable* hash_table_create(void){
     g_hash_table_insert(hash, "Light Snow Early", _("Light Snow Early"));
     g_hash_table_insert(hash, "Light Snow Late", _("Light Snow Late"));
     g_hash_table_insert(hash, "Light Snow Shower", _("Light Snow Shower"));
+    g_hash_table_insert(hash, "Light Snow / Fog", _("Light Snow / Fog"));        
     g_hash_table_insert(hash, "Low", _("Low"));
     g_hash_table_insert(hash, "Mist", _("Mist"));
     g_hash_table_insert(hash, "Mostly Clear", _("Mostly Clear"));
@@ -89,8 +94,11 @@ GHashTable* hash_table_create(void){
     g_hash_table_insert(hash, "Overcast", _("Overcast"));
     g_hash_table_insert(hash, "Partly Cloudy", _("Partly Cloudy"));
     g_hash_table_insert(hash, "Partly Cloudy / Wind", _("Partly Cloudy / Wind"));
+    g_hash_table_insert(hash, "Partly Cloudy and Windy", _("Partly Cloudy and Windy"));
     g_hash_table_insert(hash, "PM Fog", _("PM Fog"));
     g_hash_table_insert(hash, "PM Light Rain", _("PM Light Rain"));
+    g_hash_table_insert(hash, "PM Light Snow", _("PM Light Snow"));
+    g_hash_table_insert(hash, "PM Light Snow / Wind", _("PM Light Snow / Wind")); 
     g_hash_table_insert(hash, "PM Rain", _("PM Rain"));
     g_hash_table_insert(hash, "PM Rain / Wind", _("PM Rain / Wind"));
     g_hash_table_insert(hash, "PM Showers", _("PM Showers"));
@@ -103,6 +111,7 @@ GHashTable* hash_table_create(void){
     g_hash_table_insert(hash, "Rain Shower", _("Rain Shower"));
     g_hash_table_insert(hash, "Rain / Snow", _("Rain / Snow"));
     g_hash_table_insert(hash, "Rain / Snow Early", _("Rain / Snow Early"));
+    g_hash_table_insert(hash, "Rain / Snow Late", _("Rain / Snow Late"));
     g_hash_table_insert(hash, "Rain / Snow / Wind", _("Rain / Snow / Wind"));
     g_hash_table_insert(hash, "Rain / Snow Showers Late", _("Rain / Snow Showers Late"));
     g_hash_table_insert(hash, "Rain / Snow Showers", _("Rain / Snow Showers"));
@@ -127,8 +136,8 @@ GHashTable* hash_table_create(void){
     g_hash_table_insert(hash, "Snow Showers Late", _("Snow Showers Late"));
     g_hash_table_insert(hash, "Snow Shower", _("Snow Shower"));
     g_hash_table_insert(hash, "Snow Shower / Wind", _("Snow Shower / Wind"));
-    g_hash_table_insert(hash, "Snow Showers / Wind Early", _("Snow Showers / Wind Early"));
-    g_hash_table_insert(hash, "Snow Showers Early", _("Snow Showers Early"));
+    g_hash_table_insert(hash, "Snow Showers / Wind Early", _("Snows Showers / Wind Early"));
+    g_hash_table_insert(hash, "Snow Showers Early", _("Snows Showers Early"));
     g_hash_table_insert(hash, "Snow", _("Snow"));
     g_hash_table_insert(hash, "Snow / Wind", _("Snow / Wind"));
     g_hash_table_insert(hash, "Snow to Rain", _("Snow to Rain"));
